@@ -160,52 +160,63 @@ update_parse (DroplineData *data, const gchar *mesg)
 	const gchar *package_name_installed;
 	gchar *colon;
 	gchar **lines;
-	gint i, j, status;
+	gint i, j, status, dl_length;
 	gboolean found;
 	
-	lines = g_strsplit (mesg, "\n", MAX_FILES);
-	for (i = 0; lines [i]; i++)
-	{
-		if (strstr (lines [i], ":obsolete:"))
-			lines [i] = '\0';
-		else
-		{
-			colon = strstr (lines [i], ":");
-			if (colon)
-				lines [i][colon - lines [i]] = '\0';
-		}
-	}
+	dl_length = strlen ("dropline-installer");
 	
-	j = 0;
-	for (i = 0; lines [i] && lines [i][0] != '\0'; i++)
+	if (	!mesg || 
+		(strlen (mesg) < dl_length) || 
+		(strncmp (mesg, "dropline-installer", dl_length)))
 	{
-		found = FALSE;
-		package_dir = g_dir_open ("/var/log/packages", 0, NULL);
-		while ((package_name_installed = g_dir_read_name (package_dir)) && !found)
-		{
-			if (!strncmp (package_name_installed, lines [i], 
-					strlen (package_name_installed)))
-				found = TRUE;
-		}
-		g_dir_close (package_dir);
-		if (!found)
-		{
-			colon = strstr (lines [i], ".");
-			lines [i][colon - lines[i] - 2] = '\0';
-			if (!package_disliked (lines [i]))
-				j++;
-		}
+		status = STATUS_ERROR;
 	}
-
-	if (!j)
-		status = STATUS_IDLE;
 	else
-		status = STATUS_AVAILABLE;
+	{
+		lines = g_strsplit (mesg, "\n", MAX_FILES);
+		for (i = 0; lines [i]; i++)
+		{
+			if (strstr (lines [i], ":obsolete:"))
+				lines [i] = '\0';
+			else
+			{
+				colon = strstr (lines [i], ":");
+				if (colon)
+					lines [i][colon - lines [i]] = '\0';
+			}
+		}
+	
+		j = 0;
+		for (i = 0; lines [i] && lines [i][0] != '\0'; i++)
+		{
+			found = FALSE;
+			package_dir = g_dir_open ("/var/log/packages", 0, NULL);
+			while ((package_name_installed = g_dir_read_name (package_dir)) && !found)
+			{
+				if (!strncmp (package_name_installed, lines [i], 
+						strlen (package_name_installed)))
+					found = TRUE;
+			}
+			g_dir_close (package_dir);
+			if (!found)
+			{
+				colon = strstr (lines [i], ".");
+				lines [i][colon - lines[i] - 2] = '\0';
+				if (!package_disliked (lines [i]))
+					j++;
+			}
+		}
+		
+		if (!j)
+			status = STATUS_IDLE;
+		else
+			status = STATUS_AVAILABLE;
+			
+		g_strfreev (lines);
+	}
 
 	update_alert (data, status);
 	
-	g_strfreev (lines);
-	
 	return;
 }
 
@@ -247,8 +258,6 @@ net_send_request (gpointer gdata)
 	curl_easy_setopt (session, CURLOPT_URL, "http://www.dropline.net/gnome/DroplineFiles2c");
 	curl_easy_setopt (session, CURLOPT_NOPROGRESS, TRUE);
 	curl_easy_setopt (session, CURLOPT_USERAGENT, "Dropline Alert " VERSION);
-//	curl_easy_setopt (session, CURLOPT_TIMEOUT, 45);
-//	curl_easy_setopt (session, CURLOPT_NOSIGNAL, 1);
 
 	// Proxy stuff
 	if (data->proxy_enable)
